@@ -259,21 +259,17 @@ class BaseSnatch:
         data.find_current_status(
             max_days_old=max_days_old, max_periods_old=max_periods_old
         )
-        logger.info(f"Data received. Status is: {data.integration_status}")
 
         # Check Status
         if data.integration_status in ["SUCCESS", "TIMEOUT", "CONN_ERROR"]:
-            logger.info(f"Returning data. Status is: {data.integration_status}.")
             return data
 
         if data.integration_status == "WAITING":
             logger.info(f"Waiting for new data... Timeout is: {timeout} seconds.")
             wait_data = self._waiter(timeout=timeout)
-            logger.info(f"Returning data. Status is: {data.integration_status}.")
             return wait_data
 
         # Status: None, NOT_FOUND, ERROR or EXPIRED
         self._post_new_prospect(timeout)
         wait_data = self._waiter(timeout=timeout)
-        logger.info(f"Returning data. Status is: {data.integration_status}.")
         return wait_data
